@@ -1,13 +1,20 @@
 package MooseX::POE;
 
-our $VERSION = '0.204';
+our $VERSION = '0.206';
 
 use Moose ();
 use Moose::Exporter;
 
-Moose::Exporter->setup_import_methods(
-    with_caller => [qw(event)],
-    also        => 'Moose',
+my ( $import, $unimport, $init_meta ) = Moose::Exporter->setup_import_methods(
+    with_caller     => [qw(event)],
+    also            => 'Moose',
+    install         => [qw(import unimport)],
+    class_metaroles => {
+        class       => ['MooseX::POE::Meta::Trait::Class'],
+        constructor => ['MooseX::POE::Meta::Trait::Constructor'],
+        instance    => ['MooseX::POE::Meta::Trait::Instance'],
+    },
+    base_class_roles => ['MooseX::POE::Meta::Trait::Object'],
 );
 
 sub init_meta {
@@ -18,17 +25,7 @@ sub init_meta {
 
     Moose->init_meta( for_class => $for );
 
-    Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class                => $for,
-        metaclass_roles          => ['MooseX::POE::Meta::Trait::Class'],
-        constructor_class_roles  => ['MooseX::POE::Meta::Trait::Constructor'],
-        instance_metaclass_roles => ['MooseX::POE::Meta::Trait::Instance'],
-    );
-
-    Moose::Util::MetaRole::apply_base_class_roles(
-        for_class => $for,
-        roles     => ['MooseX::POE::Meta::Trait::Object']
-    );
+    goto $init_meta;
 }
 
 sub event {
@@ -46,7 +43,7 @@ MooseX::POE - The Illicit Love Child of Moose and POE
 
 =head1 VERSION
 
-This document describes MooseX::POE version 0.203
+This document describes MooseX::POE version 0.205
 
 =head1 SYNOPSIS
 
@@ -102,6 +99,9 @@ or with L<MooseX::Declare|MooseX::Declare>:
         }
     }
 
+    Counter->new();
+    POE::Kernel->run();
+
 =head1 DESCRIPTION
 
 MooseX::POE is a Moose wrapper around a POE::Session.
@@ -142,7 +142,7 @@ of methods on that class so you know what to look for:
 
 L<MooseX::Declare|MooseX::Declare> support is still "experimental". Meaning that I don't use it,
 I don't have any code that uses it, and thus I can't adequately say that it
-won't cause monkeys to fly out of any orafices on your body beyond what the
+won't cause monkeys to fly out of any orifices on your body beyond what the
 tests and the SYNOPSIS cover. 
 
 That said there are a few caveats that have turned up during testing. 
@@ -181,12 +181,15 @@ Chris Prather  C<< <chris@prather.org> >>
 
 Ash Berlin C<< <ash@cpan.org> >>
 
+Chris Williams C<<chris@bingosnet.co.uk>>
+
 Yuval (nothingmuch) Kogman 
 
 =head1 LICENCE AND COPYRIGHT
 
 Copyright (c) 2007-2009, Chris Prather C<< <chris@prather.org> >>, Ash Berlin
-C<< <ash@cpan.org> >>, Yuval (nothingmuch) Kogman. Some rights reserved.
+C<< <ash@cpan.org> >>, Chris Williams C<<chris@bingosnet.co.uk>>, Yuval
+(nothingmuch) Kogman. Some rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
