@@ -13,9 +13,11 @@ sub init_meta {
     my ($class, %args) = @_;
     MooseX::POE->init_meta(%args);
 
-    Moose::Util::MetaRole::apply_metaclass_roles(
-      for_class => $args{for_class},
-      metaclass_roles => [ 'MooseX::POE::Meta::Trait::SweetArgs' ],
+    Moose::Util::MetaRole::apply_metaroles(
+        for             => $args{for_class},
+        class_metaroles => {
+            class => ['MooseX::POE::Meta::Trait::SweetArgs'],
+        },
     );
 }
 
@@ -29,8 +31,6 @@ MooseX::POE::SweetArgs - sugar around MooseX::POE event arguments
 =head1 SYNOPSIS
 
   package Thing;
-
-  # must come before MooseX::POE!
   use MooseX::POE::SweetArgs;
 
   # declare events like usual
@@ -69,6 +69,8 @@ Chris Prather  C<< <perigrin@cpan.org> >>
 
 Ash Berlin C<< <ash@cpan.org> >>
 
+Hans Dieter Pearcey
+
 =head1 LICENCE AND COPYRIGHT
 
 Copyright (c) 2007-2009, Chris Prather C<< <perigrin@cpan.org> >>, Ash Berlin
